# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_cons.ipynb.

# %% auto 0
__all__ = ['PUNC', 'ATTR']

# %% ../nbs/01_cons.ipynb 4
import re, string

# %% ../nbs/01_cons.ipynb 6
PUNC = re.compile(rf'[{re.escape(string.punctuation)}]')

# %% ../nbs/01_cons.ipynb 8
ATTR = re.compile(r'\s+|_')
